// THIS FILE IS AUTO GENERATED
import { IconTree, IconType } from '../lib'
export declare const CiAirportSign1: IconType;
export declare const CiAlarmOff: IconType;
export declare const CiAlarmOn: IconType;
export declare const CiAlignBottom: IconType;
export declare const CiAlignCenterH: IconType;
export declare const CiAlignCenterV: IconType;
export declare const CiAlignLeft: IconType;
export declare const CiAlignRight: IconType;
export declare const CiAlignTop: IconType;
export declare const CiApple: IconType;
export declare const CiAt: IconType;
export declare const CiAvocado: IconType;
export declare const CiBacon: IconType;
export declare const CiBadgeDollar: IconType;
export declare const CiBag1: IconType;
export declare const CiBandage: IconType;
export declare const CiBank: IconType;
export declare const CiBarcode: IconType;
export declare const CiBaseball: IconType;
export declare const CiBasketball: IconType;
export declare const CiBatteryCharging: IconType;
export declare const CiBatteryEmpty: IconType;
export declare const CiBatteryFull: IconType;
export declare const CiBeaker1: IconType;
export declare const CiBeerMugFull: IconType;
export declare const CiBellOff: IconType;
export declare const CiBellOn: IconType;
export declare const CiBezier: IconType;
export declare const CiBitcoin: IconType;
export declare const CiBluetooth: IconType;
export declare const CiBookmarkCheck: IconType;
export declare const CiBookmarkMinus: IconType;
export declare const CiBookmarkPlus: IconType;
export declare const CiBookmarkRemove: IconType;
export declare const CiBookmark: IconType;
export declare const CiBowlNoodles: IconType;
export declare const CiBoxList: IconType;
export declare const CiBoxes: IconType;
export declare const CiBrightnessDown: IconType;
export declare const CiBrightnessUp: IconType;
export declare const CiBullhorn: IconType;
export declare const CiBurger: IconType;
export declare const CiCalculator1: IconType;
export declare const CiCalculator2: IconType;
export declare const CiCalendarDate: IconType;
export declare const CiCalendar: IconType;
export declare const CiCamera: IconType;
export declare const CiChat1: IconType;
export declare const CiChat2: IconType;
export declare const CiCircleAlert: IconType;
export declare const CiCircleCheck: IconType;
export declare const CiCircleChevDown: IconType;
export declare const CiCircleChevLeft: IconType;
export declare const CiCircleChevRight: IconType;
export declare const CiCircleChevUp: IconType;
export declare const CiCircleInfo: IconType;
export declare const CiCircleList: IconType;
export declare const CiCircleMinus: IconType;
export declare const CiCircleMore: IconType;
export declare const CiCirclePlus: IconType;
export declare const CiCircleQuestion: IconType;
export declare const CiCircleRemove: IconType;
export declare const CiClock1: IconType;
export declare const CiClock2: IconType;
export declare const CiCloudDrizzle: IconType;
export declare const CiCloudMoon: IconType;
export declare const CiCloudOff: IconType;
export declare const CiCloudOn: IconType;
export declare const CiCloudRainbow: IconType;
export declare const CiCloudSun: IconType;
export declare const CiCloud: IconType;
export declare const CiCoffeeBean: IconType;
export declare const CiCoffeeCup: IconType;
export declare const CiCoinInsert: IconType;
export declare const CiCoins1: IconType;
export declare const CiCompass1: IconType;
export declare const CiCreditCard1: IconType;
export declare const CiCreditCard2: IconType;
export declare const CiCreditCardOff: IconType;
export declare const CiCrop: IconType;
export declare const CiDark: IconType;
export declare const CiDatabase: IconType;
export declare const CiDeliveryTruck: IconType;
export declare const CiDesktopMouse1: IconType;
export declare const CiDesktopMouse2: IconType;
export declare const CiDesktop: IconType;
export declare const CiDiscount1: IconType;
export declare const CiDollar: IconType;
export declare const CiDroplet: IconType;
export declare const CiDumbbell: IconType;
export declare const CiEdit: IconType;
export declare const CiEraser: IconType;
export declare const CiExport: IconType;
export declare const CiFaceFrown: IconType;
export declare const CiFaceMeh: IconType;
export declare const CiFaceSmile: IconType;
export declare const CiFacebook: IconType;
export declare const CiFileOff: IconType;
export declare const CiFileOn: IconType;
export declare const CiFilter: IconType;
export declare const CiFlag1: IconType;
export declare const CiFloppyDisk: IconType;
export declare const CiFolderOff: IconType;
export declare const CiFolderOn: IconType;
export declare const CiFootball: IconType;
export declare const CiForkAndKnife: IconType;
export declare const CiFries: IconType;
export declare const CiGift: IconType;
export declare const CiGlass: IconType;
export declare const CiGlobe: IconType;
export declare const CiGps: IconType;
export declare const CiGrid2H: IconType;
export declare const CiGrid2V: IconType;
export declare const CiGrid31: IconType;
export declare const CiGrid32: IconType;
export declare const CiGrid41: IconType;
export declare const CiGrid42: IconType;
export declare const CiHardDrive: IconType;
export declare const CiHashtag: IconType;
export declare const CiHeadphones: IconType;
export declare const CiHeart: IconType;
export declare const CiHome: IconType;
export declare const CiHospital1: IconType;
export declare const CiHotdog: IconType;
export declare const CiIceCream: IconType;
export declare const CiImageOff: IconType;
export declare const CiImageOn: IconType;
export declare const CiImport: IconType;
export declare const CiInboxIn: IconType;
export declare const CiInboxOut: IconType;
export declare const CiIndent: IconType;
export declare const CiInstagram: IconType;
export declare const CiKeyboard: IconType;
export declare const CiLaptop: IconType;
export declare const CiLemon: IconType;
export declare const CiLight: IconType;
export declare const CiLineHeight: IconType;
export declare const CiLink: IconType;
export declare const CiLinkedin: IconType;
export declare const CiLocationArrow1: IconType;
export declare const CiLocationOff: IconType;
export declare const CiLocationOn: IconType;
export declare const CiLock: IconType;
export declare const CiLogin: IconType;
export declare const CiLogout: IconType;
export declare const CiLollipop: IconType;
export declare const CiMail: IconType;
export declare const CiMapPin: IconType;
export declare const CiMap: IconType;
export declare const CiMaximize1: IconType;
export declare const CiMaximize2: IconType;
export declare const CiMedal: IconType;
export declare const CiMedicalCase: IconType;
export declare const CiMedicalClipboard: IconType;
export declare const CiMedicalCross: IconType;
export declare const CiMedicalMask: IconType;
export declare const CiMemoPad: IconType;
export declare const CiMenuBurger: IconType;
export declare const CiMenuFries: IconType;
export declare const CiMenuKebab: IconType;
export declare const CiMicrochip: IconType;
export declare const CiMicrophoneOff: IconType;
export declare const CiMicrophoneOn: IconType;
export declare const CiMinimize1: IconType;
export declare const CiMinimize2: IconType;
export declare const CiMobile1: IconType;
export declare const CiMobile2: IconType;
export declare const CiMobile3: IconType;
export declare const CiMobile4: IconType;
export declare const CiMoneyBill: IconType;
export declare const CiMoneyCheck1: IconType;
export declare const CiMonitor: IconType;
export declare const CiMountain1: IconType;
export declare const CiMug1: IconType;
export declare const CiMusicNote1: IconType;
export declare const CiNoWaitingSign: IconType;
export declare const CiPalette: IconType;
export declare const CiPaperplane: IconType;
export declare const CiParking1: IconType;
export declare const CiPassport1: IconType;
export declare const CiPause1: IconType;
export declare const CiPen: IconType;
export declare const CiPenpot: IconType;
export declare const CiPercent: IconType;
export declare const CiPhone: IconType;
export declare const CiPickerEmpty: IconType;
export declare const CiPickerHalf: IconType;
export declare const CiPill: IconType;
export declare const CiPillsBottle1: IconType;
export declare const CiPizza: IconType;
export declare const CiPlane: IconType;
export declare const CiPlay1: IconType;
export declare const CiPlug1: IconType;
export declare const CiPower: IconType;
export declare const CiRainbow: IconType;
export declare const CiRead: IconType;
export declare const CiReceipt: IconType;
export declare const CiRedo: IconType;
export declare const CiRepeat: IconType;
export declare const CiRollingSuitcase: IconType;
export declare const CiRoute: IconType;
export declare const CiRouter: IconType;
export declare const CiRuler: IconType;
export declare const CiSatellite1: IconType;
export declare const CiSaveDown1: IconType;
export declare const CiSaveDown2: IconType;
export declare const CiSaveUp1: IconType;
export declare const CiSaveUp2: IconType;
export declare const CiSearch: IconType;
export declare const CiServer: IconType;
export declare const CiSettings: IconType;
export declare const CiShare1: IconType;
export declare const CiShare2: IconType;
export declare const CiShirt: IconType;
export declare const CiShop: IconType;
export declare const CiShoppingBasket: IconType;
export declare const CiShoppingCart: IconType;
export declare const CiShoppingTag: IconType;
export declare const CiShuffle: IconType;
export declare const CiSignpostDuo1: IconType;
export declare const CiSignpostL1: IconType;
export declare const CiSignpostR1: IconType;
export declare const CiSliderHorizontal: IconType;
export declare const CiSliderVertical: IconType;
export declare const CiSpeaker: IconType;
export declare const CiSquareAlert: IconType;
export declare const CiSquareCheck: IconType;
export declare const CiSquareChevDown: IconType;
export declare const CiSquareChevLeft: IconType;
export declare const CiSquareChevRight: IconType;
export declare const CiSquareChevUp: IconType;
export declare const CiSquareInfo: IconType;
export declare const CiSquareMinus: IconType;
export declare const CiSquareMore: IconType;
export declare const CiSquarePlus: IconType;
export declare const CiSquareQuestion: IconType;
export declare const CiSquareRemove: IconType;
export declare const CiStar: IconType;
export declare const CiStethoscope: IconType;
export declare const CiStickyNote: IconType;
export declare const CiStop1: IconType;
export declare const CiStopSign1: IconType;
export declare const CiStopwatch: IconType;
export declare const CiStreamOff: IconType;
export declare const CiStreamOn: IconType;
export declare const CiSun: IconType;
export declare const CiTablets1: IconType;
export declare const CiTempHigh: IconType;
export declare const CiTextAlignCenter: IconType;
export declare const CiTextAlignJustify: IconType;
export declare const CiTextAlignLeft: IconType;
export declare const CiTextAlignRight: IconType;
export declare const CiText: IconType;
export declare const CiTimer: IconType;
export declare const CiTrash: IconType;
export declare const CiTrophy: IconType;
export declare const CiTurnL1: IconType;
export declare const CiTurnR1: IconType;
export declare const CiTwitter: IconType;
export declare const CiUmbrella: IconType;
export declare const CiUndo: IconType;
export declare const CiUnlock: IconType;
export declare const CiUnread: IconType;
export declare const CiUsb: IconType;
export declare const CiUser: IconType;
export declare const CiVault: IconType;
export declare const CiVial: IconType;
export declare const CiVideoOff: IconType;
export declare const CiVideoOn: IconType;
export declare const CiViewBoard: IconType;
export declare const CiViewColumn: IconType;
export declare const CiViewList: IconType;
export declare const CiViewTable: IconType;
export declare const CiViewTimeline: IconType;
export declare const CiVirus: IconType;
export declare const CiVoicemail: IconType;
export declare const CiVolumeHigh: IconType;
export declare const CiVolumeMute: IconType;
export declare const CiVolume: IconType;
export declare const CiWallet: IconType;
export declare const CiWarning: IconType;
export declare const CiWavePulse1: IconType;
export declare const CiWheat: IconType;
export declare const CiWifiOff: IconType;
export declare const CiWifiOn: IconType;
export declare const CiYoutube: IconType;
export declare const CiZoomIn: IconType;
export declare const CiZoomOut: IconType;
